@@ -1,21 +1,8 @@
 /*
- *  Author : Simon MARTIN <simartin@users.sourceforge.net>
- *  Copyright (c) 2004 Simon MARTIN <simartin@users.sourceforge.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+  SPDX-FileCopyrightText: 2004 Simon MARTIN <simartin@users.sourceforge.net>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterevolution.h"
 
@@ -202,7 +189,9 @@ void FilterEvolution::importMBox(const QString &mboxName, const QString &rootDir
                 destFolder = QLatin1String("Evolution-Import/") + destFolder;
             }
 
-            importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage());
+            if (!importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+            }
 
             const int currentPercentage = (int)(((float)mbox.pos() / filenameInfo.size()) * 100);
             filterInfo()->setCurrent(currentPercentage);
