@@ -1,19 +1,13 @@
-/***************************************************************************
-            filter_evolution_v2.cxx  -  Evolution 2.0.x mail import
-                             -------------------
-    begin                : Januar 26 2005
-    copyright            : (C) 2005 by Danny Kukawka <danny.kukawka@web.de>
-                           (inspired and partly copied from filter_evolution)
- ***************************************************************************/
+/*
+  filterevolution_v2.cpp  -  Evolution 2.0.x mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
+
+  Inspired and partly copied from filterevolution
+  SPDX-FileCopyrightText: 2004 Simon MARTIN <simartin@users.sourceforge.net>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterevolution_v2.h"
 
@@ -264,7 +258,9 @@ void FilterEvolution_v2::importMBox(const QString &mboxName, const QString &root
                 }
             }
 
-            importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage());
+            if (!importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+            }
 
             int currentPercentage = (int)(((float)mbox.pos() / filenameInfo.size()) * 100);
             filterInfo()->setCurrent(currentPercentage);
