@@ -1,21 +1,9 @@
-/* Copyright 2009,2010 Klarälvdalens Datakonsult AB
+/*
+   SPDX-FileCopyrightText: 2009, 2010 Klarälvdalens Datakonsult AB
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
+
 #include "filterkmailarchive.h"
 
 #include <KLocalizedString>
@@ -36,10 +24,6 @@ using namespace MailImporter;
 class MailImporter::FilterKMailArchivePrivate
 {
 public:
-    FilterKMailArchivePrivate()
-    {
-    }
-
     int mTotalFiles = 0;
     int mFilesDone = 0;
 };
@@ -98,7 +82,7 @@ bool FilterKMailArchive::importFolder(const KArchiveDirectory *folder, const QSt
         const QStringList lstEntries = messageDir->entries();
         for (const QString &entryName : lstEntries) {
             filterInfo()->setCurrent(cur * 100 / total);
-            filterInfo()->setOverall(d->mFilesDone * 100 / d->mTotalFiles);
+            filterInfo()->setOverall(d->mTotalFiles == 0 ? 0 : (d->mFilesDone * 100 / d->mTotalFiles));
             const KArchiveEntry *const entry = messageDir->entry(entryName);
 
             if (entry->isFile()) {
@@ -131,7 +115,7 @@ bool FilterKMailArchive::importDirectory(const KArchiveDirectory *directory, con
         const KArchiveEntry *const entry = directory->entry(entryName);
 
         if (entry->isDirectory()) {
-            const KArchiveDirectory *dir = static_cast<const KArchiveDirectory *>(entry);
+            const auto *dir = static_cast<const KArchiveDirectory *>(entry);
 
             if (!dir->name().startsWith(QLatin1Char('.'))) {
                 if (!importFolder(dir, folderPath + QLatin1Char('/') + dir->name())) {
